import unittest
from unittest.mock import patch

from click.testing import CliRunner

from ebenezer.commands.volume import cli


class TestVolumeCommands(unittest.TestCase):
    def setUp(self):
        self.runner = CliRunner()

    @patch("ebenezer.commands.volume.run_command")
    @patch("ebenezer.commands.volume.click.echo")
    def test_volume_level(self, mock_click_echo, mock_run_command):
        mock_run_command.return_value = "50%"

        result = self.runner.invoke(cli, ["level"])

        mock_run_command.assert_called_once_with(
            "pactl list sinks | grep 'Volume:' | head -n 1 | awk '{print $5}' | tail -n 1 | grep -o '[0-9]\\+'"
        )
        mock_click_echo.assert_called_once_with("50%")

    @patch("ebenezer.commands.volume.run_command")
    @patch("ebenezer.commands.volume.click.echo")
    def test_volume_up(self, mock_click_echo, mock_run_command):
        result = self.runner.invoke(cli, ["up"])

        mock_run_command.assert_called_once_with(
            "pactl set-sink-volume @DEFAULT_SINK@ +5%"
        )
        mock_click_echo.assert_called_once_with("Volume increased by 5%")

    @patch("ebenezer.commands.volume.run_command")
    @patch("ebenezer.commands.volume.click.echo")
    def test_volume_down(self, mock_click_echo, mock_run_command):
        result = self.runner.invoke(cli, ["down"])

        mock_run_command.assert_called_once_with(
            "pactl set-sink-volume @DEFAULT_SINK@ -5%"
        )
        mock_click_echo.assert_called_once_with("Volume decreased by 5%")

    @patch("ebenezer.commands.volume.run_command")
    @patch("ebenezer.commands.volume.click.echo")
    def test_mute_on(self, mock_click_echo, mock_run_command):
        result = self.runner.invoke(cli, ["mute-on"])

        mock_run_command.assert_called_once_with("pactl set-sink-mute @DEFAULT_SINK@ 1")
        mock_click_echo.assert_called_once_with("Mute on")

    @patch("ebenezer.commands.volume.run_command")
    @patch("ebenezer.commands.volume.click.echo")
    def test_mute_off(self, mock_click_echo, mock_run_command):
        result = self.runner.invoke(cli, ["mute-off"])

        mock_run_command.assert_called_once_with("pactl set-sink-mute @DEFAULT_SINK@ 0")
        mock_click_echo.assert_called_once_with("Mute off")

    @patch("ebenezer.commands.volume.run_command")
    @patch("ebenezer.commands.volume.click.echo")
    def test_mute_toggle(self, mock_click_echo, mock_run_command):
        result = self.runner.invoke(cli, ["mute-toggle"])

        mock_run_command.assert_called_once_with(
            "pactl set-sink-mute @DEFAULT_SINK@ toggle"
        )
        mock_click_echo.assert_called_once_with("Mute toggled")

    @patch("ebenezer.commands.volume.run_command")
    @patch("ebenezer.commands.volume.click.echo")
    def test_mute_mic(self, mock_click_echo, mock_run_command):
        result = self.runner.invoke(cli, ["mute-mic"])

        mock_run_command.assert_called_once_with(
            "pactl set-source-mute @DEFAULT_SOURCE@ toggle"
        )
        mock_click_echo.assert_called_once_with("Microphone mute toggled")


if __name__ == "__main__":
    unittest.main()



import click

from ebenezer.commands.helpers import run_command


def get_volume_level() -> str:
    command = "pactl list sinks | grep 'Volume:' | head -n 1 | awk '{print $5}' | tail -n 1 | grep -o '[0-9]\\+'"
    return run_command(command)


@click.group()
def cli():
    pass


@cli.command()
def level():
    level = get_volume_level()
    click.echo(level)


@cli.command()
def up():
    volume_up()
    click.echo("Volume increased by 5%")


@cli.command()
def down():
    volume_down()
    click.echo("Volume decreased by 5%")


@cli.command()
def mute_toggle():
    volume_mute_toggle()
    click.echo("Mute toggled")


@cli.command()
def mute_on():
    volume_mute_on()
    click.echo("Mute on")


@cli.command()
def mute_off():
    volume_mute_off()
    click.echo("Mute off")


@cli.command()
def mute_status():
    status = volume_mute_status()
    click.echo(status)


@cli.command()
def mute_mic():
    microphone_mute_toggle()
    click.echo("Microphone mute toggled")


def volume_up():
    command = "pactl set-sink-volume @DEFAULT_SINK@ +5%"
    run_command(command)


def volume_down():
    command = "pactl set-sink-volume @DEFAULT_SINK@ -5%"
    run_command(command)


def volume_mute_toggle():
    command = "pactl set-sink-mute @DEFAULT_SINK@ toggle"
    run_command(command)


def volume_mute_on():
    command = "pactl set-sink-mute @DEFAULT_SINK@ 1"
    run_command(command)


def volume_mute_off():
    command = "pactl set-sink-mute @DEFAULT_SINK@ 0"
    run_command(command)


def volume_mute_status():
    command = "pactl list sinks | grep 'Mute:' | head -n 1 | awk '{print $2}'"
    return run_command(command)


def microphone_mute_toggle():
    command = "pactl set-source-mute @DEFAULT_SOURCE@ toggle"
    run_command(command)


if __name__ == "__main__":
    cli()
